import type { OutputBundle } from 'rollup';
import type { ExcludeFilepathOption } from './utils';
export type WebpackStatsFilteredAsset = {
    name: string;
    size?: number;
};
export interface WebpackStatsFilteredChunk {
    id: number | string;
    entry: boolean;
    initial: boolean;
    files?: Array<string>;
    names?: Array<string>;
}
export interface WebpackStatsFilteredModule {
    name: string;
    size?: number;
    chunks: Array<string | number>;
}
export interface WebpackStatsFilteredConcatenatedModule {
    name: string;
    size?: number;
}
export interface WebpackStatsFilteredRootModule extends WebpackStatsFilteredModule {
    modules?: Array<WebpackStatsFilteredConcatenatedModule>;
}
export interface WebpackStatsFiltered {
    builtAt?: number;
    hash?: string;
    assets?: Array<WebpackStatsFilteredAsset>;
    chunks?: Array<WebpackStatsFilteredChunk>;
    modules?: Array<WebpackStatsFilteredRootModule>;
}
export type BundleTransformOptions = {
    /**
     * Extract module original size or rendered size
     * default: false
     */
    moduleOriginalSize?: boolean;
    /**
     * Exclude matching assets
     */
    excludeAssets?: ExcludeFilepathOption;
    /**
     * Exclude matching modules
     */
    excludeModules?: ExcludeFilepathOption;
    /**
     * Transform function to access and mutate the resulting stats after the convertion
     */
    transform?: (stats: WebpackStatsFiltered) => WebpackStatsFiltered;
};
export declare const bundleToWebpackStats: (bundle: OutputBundle, pluginOptions?: BundleTransformOptions) => WebpackStatsFiltered;
